---
layout: default
title: Frontiers
---

# Frontiers

Frontiers keep track of three sets of URIs:

* Current URIs that are being processed
* Staged URIs that might be processed in the next cycle
* Cached URIs that have been processed

All frontiers expose the same behaviour.

<pre class="illustration">
┌──────────────────────────────────────────────────────────┐
│                          STAGED                          │
│          {https://alpha.com, https://beta.com}           │
└──────────────────────────────────────────────────────────┘
┌──────────────────────────────────────────────────────────┐
│                         CURRENT                          │
│                   {https://gamma.com}                    │
└──────────────────────────────────────────────────────────┘
┌──────────────────────────────────────────────────────────┐
│                          CACHED                          │
│                    {https://beta.com}                    │
└──────────────────────────────────────────────────────────┘
                             │
                           Cycle
                             │
                             ▼
┌──────────────────────────────────────────────────────────┐
│                         STAGED'                          │
│                          {...}                           │
└──────────────────────────────────────────────────────────┘
┌──────────────────────────────────────────────────────────┐
│                CURRENT' = STAGED \ CACHED                │
│                   {https://alpha.com}                    │
└──────────────────────────────────────────────────────────┘
┌──────────────────────────────────────────────────────────┐
│                CACHED' = CACHED ∪ CURRENT                │
│          {https://beta.com, https://gamma.com}           │
└──────────────────────────────────────────────────────────┘
</pre>

## Available frontiers
Currently, there are 5 frontiers available:

2. `:memory` (default): Uses sets from the standard lib.
4. `:redis`: Uses Redis sets.
3. `:memory_bloom`: Uses a [Bloom filter](https://github.com/igrigorik/bloomfilter-rb).
5. `:redis_bloom`: Uses a Redis-backed Bloom filter.
1. `:memory_trie`: Uses a [trie](https://github.com/tyler/trie) and sets.

| Frontier | MRI support | JRuby support |
| --- | --- |
| `:memory` | Yes | Yes
| `:redis` | Yes | Yes
| `:memory_bloom` | Yes | No
| `:redis_bloom` | Yes | No
| `:memory_trie` | Yes | No

## Setting the frontier

Set the `:frontier` configuration key:

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  config.frontier = :foobar
end
{% endhighlight %}

### Using a Redis frontier

Set the `:redis_opts` and `:frontier` configuration keys:

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  config.redis_opts = { port: 4242 }
  config.frontier = :redis
end
{% endhighlight %}

### Setting bloomfilter parameters

Set the `:bloomfilter_opts` configuration key:

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  config.bloomfilter_opts = { ... }
end
{% endhighlight %}