---
layout: default
title: Locals
---

# Locals

Locals are Wayfarer's replacement for job instance variables. Both `let` and `let!` declare variables that are accessible within [callbacks]({{base}}/callbacks.html) and actions.

Even though you might recognise them from RSpec, they have differing semantics: Values in `let` blocks will be replaced with thread-safe counterparts once the job is run. `let!` skips this. Both evaluate their block immediately.

| Standard lib | Counterpart |
| --- | --- |
| Booleans | [`Concurrent::AtomicBoolean`](http://ruby-concurrency.github.io/concurrent-ruby/Concurrent/AtomicBoolean.html) |
| `Fixnum` | [`Concurrent::AtomicFixnum`](http://ruby-concurrency.github.io/concurrent-ruby/Concurrent/AtomicFixnum.html) |
| `Hash` | [`Concurrent::Hash`](http://ruby-concurrency.github.io/concurrent-ruby/Concurrent/Hash.html) |
| `Array` | [`Concurrent::Array`](http://ruby-concurrency.github.io/concurrent-ruby/Concurrent/Array.html) |
| Everything else | Untouched |

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  let(:values) { [1, 2, 3] }

  before_crawl do
    values.reverse!
  end

  after_crawl do
    values # => [3, 2, 1, 0]
  end

  def some_action
    values << 0
  end
end
{% endhighlight %}
