---
layout: default
title: Peeking
---

# Peeking
Peeking allows bypassing the [frontier](frontiers.html) in an ad-hoc manner. Use Ruby's `yield` keyword to immediately retrieve and dispatch a URI from within actions. Control gets handed off to the action matching the yielded URI, if any.

A matching route for the yielded URI is still required. If the yielded URI matches no route or raises an exception, `yield` returns `nil`.

<aside class="note">
The action that gets the URI dispatched to <strong>will</strong> get assigned another HTTP adapter! HTTP adapters are never shared across actions, i.e. if you're using the Selenium HTTP adapter, the peeked URI gets retrieved by a different browser process.
</aside>

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.uri "https://example.com", to: :foo
  route.uri "https://w3c.org", to: :bar

  def foo
    w3c_page = yield "https://w3c.org"
  end

  def bar
    page
  end
end
{% endhighlight %}

__Recursive peeking does not work__, or else peeking might result in an infinite loop. The following does terminate:

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.uri "https://example.com", to: :foo
  route.uri "https://w3c.org", to: :bar

  def foo
    w3c_page = yield "https://w3c.org"
  end

  def bar
    # Silently ignored, assigns nil
    example_page = yield "https://example.com"
  end
end
{% endhighlight %}
