---
layout: default
title: Versatile web crawling with (J)Ruby
---

# Versatile web crawling with (J)Ruby

Wayfarer is the swiss army knife for web crawling.

MRI:
```
% [sudo] gem install wayfarer
```

JRuby:
```
% [sudo] gem install wayfarer-jruby
```

If you …

* __Need to crawl page graphs breadth-first__
* __Need to extract whatever data__
* Do it multi-threaded
* Integrate with Rails seamlessly
* Want to automate a web browser
* Need to execute arbitrary JavaScript
* Need URI normalization
* Need to take screenshots
* Want to use a job queue and make work happen later
* Want in-memory and Redis-backed frontiers, tries and Bloom filters

… then you might like Wayfarer!

## What it looks like

Say you want to …

* Automate Google Chrome
* Start off with a random Wikipedia article
* Follow all links until you find a page with the word "Foobar"
* Take a screenshot of the page containing "Foobar"
* Extract keywords from every page you encounter
* Use 4 threads and Chrome processes to do so

This amounts to 16 lines of code with Wayfarer:

{% highlight ruby %}
require "wayfarer"

class FindFoobarOnWikipedia < Wayfarer::Job
  config.http_adapter = :selenium
  config.selenium_argv = [:chrome]
  config.connection_count = 4

  let(:keywords) { [] }

  route.host "en.wikipedia.org", to: :article

  def article
    if page.body =~ /Foobar/
      driver.save_screenshot("/tmp/foobar.png")
      return halt
    end

    keywords << page.keywords
    stage page.links
  end
end

FindFoobarOnWikipedia.perform_now("https://en.wikipedia.org/wiki/Special:Random")
{% endhighlight %}

Wayfarer integrates with [ActiveJob]() and supports your favorite job queue out of the box. Your job is ready to be enqueued:
{% highlight ruby %}
FindFoobarOnWikipedia.perform_later("https://en.wikipedia.org/wiki/Special:Random")
{% endhighlight %}

### Where to go from here

* [The tutorial]() shows how to collect all open issues from a GitHub repository
* Read the [API documentation]()
