---
layout: default
title: Path rules
---

# Path rules

Path rules match against the path of a URI. Both strings and RegExps are accepted, and path segment pattern matching and RegExp captures are supported.

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.path "/:alpha/:beta", to: :foo
  route.path /^foobar\/(.+)/, to: :bar

  def foo
    params[:alpha]
    params[:beta]
  end

  def foo
    params["0"]
  end
end
{% endhighlight %}

Matches:

* All URIs with path segments matching `/:alpha/:beta`, e.g. `https://example.com/foo/bar`
* All URIs starting with `"/foobar/"`.

<aside class="note">
<code>/:alpha/:beta</code> and <code>:alpha/:beta</code> are not considered equal. Note the opening slash.
</aside>
