---
layout: default
title: Query rules
---

# Query rules

Query rules impose constraints on key-value query parameters. Strings, integers, RegExps and ranges are supported.

## String constraints

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.query arg: "foo"
end
{% endhighlight %}

* Matches `https://example.com?arg=foo`.

## Integer constraints

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.query arg: 42
end
{% endhighlight %}

* Matches `https://example.com?arg=42`.

---

## RegExp constraints

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.query arg: /foo/
end
{% endhighlight %}

* Matches `https://example.com?arg=foo`.
* Matches `https://example.com?arg=foobar`.

---

## Range constraints

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.query arg: 1..10
end
{% endhighlight %}

* Matches `https://example.com?arg=1`.
* Matches […]
* Matches `https://example.com?arg=10`.

---

## Compound constraints

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.query foo: 1..5, bar: /baz/, qux: "zot", toto: 2
end
{% endhighlight %}

* Matches `https://example.com?foo=4&bar=bazqux&qux=zot&toto=2`.

---