---
layout: default
title: Routes
categories: [Routing]
---

# Routes

* Routes are filters for interesting URIs.
* Routes put constraints on URIs that should get processed.
* Routes map URIs to instance methods (actions).
* Routes are tree nodes and thus nestable.

Currently, the following rules are available:

* [URI rules](uri_rules.html) match URIs against a string.
* [Host rules](/routing/host_rules.html) match hosts against strings and RegExps.
* [Path rules](/routing/path_rules.html) match paths against pattern strings and RegExps. They support  path segment capturing.
* [Query rules](/routing/query_rules.html) match key-value pairs of query parameters against strings, integers, RegExps and ranges.

Routes can be fordidden. URIs that match forbidden rules are never processed.

## Route declaration

### Declaration order matching

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.host "example.com", to: :foo
  route.path "/foo", to: :bar

  # Is equivalent to:
  #
  # routes do
  #   host "example.com", to: :foo
  #   path "/foo", to: :bar
  # end
end
{% endhighlight %}

* Dispatches `https://example.com/foo` to `:foo`.
* Dispatches `https://example.com` to `:foo`.
* Dispatches `https://yahoo.com/foo` to `:bar`.

---

### Nesting routes (child rules)

A route matches if it has a child rule that matches. This applies recursively.

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.host "example.com", to: :foo do
    path "/foo"
  end

  # Is equivalent to:
  #
  # route.host "example.com", path: "/foo", to: :foo
  # route.path "/foo", host: "example.com", to: :foo
end
{% endhighlight %}

* Dispatches `https://example.com/foo` to `:foo`.
* Does not dispatch `https://example.com`.
* Does not dispatch `https://yahoo.com/foo`.

---

### Deepest routes override actions

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.host "example.com", to: :foo do
    path "/foo", to: :bar
  end
end
{% endhighlight %}

* Dispatches `https://example.com/foo` to `:bar`.
* Does not dispatch `https://example.com`.
* Does not dispatch `https://yahoo.com/foo`.

---

### Forbidding rules

{% highlight ruby %}
class DummyJob < Wayfarer::Job
  route.forbid.path "/foo"
  route.host "example.com", to: :foo
end
{% endhighlight %}

* Dispatches `https://example.com` to `:bar`.
* Does not dispatch `https://example.com/foo`.
