require_relative "../lib/wayfarer"

class CollectGithubIssues < Wayfarer::Job
  config.connection_count = 4
  config.logger.level = :fatal

  let(:records) { [] }

  routes do
    host "github.com" do
      path "/:user/:repo",            to: :repository
      path "/:user/:repo/issues",     to: :index
      path "/:user/:repo/issues/:id", to: :show
    end
  end

  after_crawl do
    records.each do |issue|
      # Save them somewhere?
      puts issue
    end
  end

  def repository
    stage navigation_links
  end

  def index
    stage issue_listing_links, next_page
  end

  def show
    return halt if records.count > 30

    records << {
      id: params[:id],
      title: issue_title,
      author: issue_author
    }
  end

  private

  def issue_title
    doc.css(".js-issue-title").text.strip
  end

  def issue_author
    doc.css(".TableObject-item .author").text.strip
  end

  def navigation_links
    page.links ".reponav-item"
  end

  def issue_listing_links
    page.links ".issues-listing"
  end

  def next_page
    page.links ".next_page"
  end
end

CollectGithubIssues.perform_now("https://github.com/rails/rails")