# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer::Crawl do
  let(:uris) { %w(http://example.com) }
  let(:job) { Class.new(Wayfarer::Job) }
  subject(:crawl) { Crawl.new(job, *uris) }

  describe "#frontier" do
    context "by default" do
      it "returns a MemoryFrontier" do
        expect(crawl.frontier).to be_a MemoryFrontier
      end
    end

    context "when Redis frontier is used", redis: true do
      before { job.config.frontier = :redis }

      it "returns a MemoryFrontier" do
        expect(crawl.frontier).to be_a RedisFrontier
      end
    end

    context "when memory bloomfilter is used", mri_only: true do
      before { job.config.frontier = :memory_bloom }

      it "returns a MemoryBloomfilter" do
        expect(crawl.frontier).to be_a MemoryBloomfilter
      end
    end

    context "when Redis bloomfilter is used", mri_only: true, redis: true do
      before { job.config.frontier = :redis_bloom }

      it "returns a RedisBloomfilter" do
        expect(crawl.frontier).to be_a RedisBloomfilter
      end
    end

    context "when memory trie is used", mri_only: true do
      before { job.config.frontier = :memory_trie }

      it "returns a RedisBloomfilter" do
        expect(crawl.frontier).to be_a MemoryTrieFrontier
      end
    end
  end
end