# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer::Frontiers::NormalizeURIs, mri_only: true do
  let(:config) { Wayfarer.config }

  let(:uris) do
    %w(
      http://example.com/foo?bar=1&zet=0
      http://example.com//foo?zet=0&bar=1
      http://example.com/foo?bar=1&zet=0#bar
    )
  end

  subject(:frontier) do
    MemoryFrontier.new(config).extend(NormalizeURIs)
  end

  describe "#stage" do
    it "normalizes URIs" do
      expect {
        frontier.stage(*uris)
      }.to change { frontier.staged_uris.count }.by(1)
    end
  end

  describe "#staged?" do
    it "normalizes URIs" do
      frontier.stage(*uris)
      uris.each { |u| expect(frontier.staged?(u)).to be true }
    end
  end

  describe "#cache, #cached?" do
    they "normalize URIs" do
      frontier.cache(*uris)
      uris.each { |u| expect(frontier.cached?(u)).to be true }
    end
  end

  context "with normalization options" do
    let(:config) do
      Configuration.new(normalize_uri_options: { remove_hash: false })
    end

    let(:uris) do
      %w(
        http://example.com/foo
        http://example.com/foo#bar
      )
    end

    it "adheres to options" do
      expect {
        frontier.stage(*uris)
      }.to change { frontier.staged_uris.count }.by(2)
    end
  end
end
