# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer, integration: true do
  describe "Callbacks" do
    subject(:job) do
      Class.new(Wayfarer::Job) do
        config.reraise_exceptions = true
      end
    end

    describe "ActiveJob-inherited callbacks" do
      they "fire" do
        job.class_eval do
          before_perform { fail }
        end

        expect {
          job.perform_now
        }.to raise_error
      end
    end

    describe "Own callbacks" do
      describe "::before_crawl" do
        it "fires" do
          job.class_eval { before_crawl { fail } }

          expect { job.perform_now }.to raise_error
        end
      end

      describe "::after_crawl" do
        it "fires" do
          job.class_eval { after_crawl { fail } }

          expect { job.perform_now }.to raise_error
        end
      end
    end
  end
end
