# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer, integration: true do
  describe "Locals" do
    subject(:job) do
      Class.new(Wayfarer::Job) do
        config.reraise_exceptions = true
      end
    end

    describe "Initial local values" do
      let(:entry) { test_app("/hello_world") }

      they "do not change" do
        job.class_eval do
          route.path "/hello_world", to: :foobar

          let(:foo) { {} }

          def foobar
            foo[:bar] = :qux
          end
        end

        expect {
          job.perform_now(entry)
        }.not_to change { job.locals[:foo] }
      end

      context "when declared with ::let" do
        they "get replaced with thread-safe counterparts" do
          job.class_eval do
            route.path "/hello_world", to: :foobar

            let(:hash) { {} }
            let(:array) { [] }
            let(:fixnum) { 123 }
            let(:tru) { true }
            let(:fuls) { false }

            def foobar
              fail unless hash.is_a? Concurrent::Hash
              fail unless array.is_a? Concurrent::Array
              fail unless fixnum.is_a? Concurrent::AtomicFixnum
              fail unless tru.is_a? Concurrent::AtomicBoolean
              fail unless fuls.is_a? Concurrent::AtomicBoolean
            end
          end

          expect {
            job.perform_now(entry)
          }.not_to raise_error
        end
      end
    end

    describe "Locals" do
      let(:entry) { test_app("/graph/index.html") }

      they "can be mutated within actions" do
        job.class_eval do
          route.path "/graph/index.html", to: :index
          route.path "/graph/details/a.html", to: :detail

          let(:hash) { {} }

          def index
            hash[:foo] = 42
            stage page.links
          end

          def detail
            fail unless hash[:foo] == 42
          end
        end

        expect {
          job.perform_now(entry)
        }.not_to raise_error
      end

      they "are accessible within callbacks" do
        job.class_eval do
          route.path "/graph/index.html", to: :index

          let(:hash) { { foo: :bar} }

          before_crawl do
            fail unless hash[:foo] == :bar
          end

          after_crawl do
            fail unless hash[:foo] == :qux
          end

          def index
            hash[:foo] = :qux
          end
        end

        expect { job.perform_now(entry) }.not_to raise_error
      end
    end
  end
end
