# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer, integration: true do
  subject(:job) do
    Class.new(Wayfarer::Job) do
      config.reraise_exceptions = true
    end
  end

  let(:entry) { test_app("/graph/index.html") }

  describe "Peeking" do
    it "works" do
      job.class_eval do
        route.path "/graph/index.html", to: :index
        route.path "/graph/details/a.html", to: :detail

        def index
          peek = yield "http://localhost:9876/graph/details/a.html"
          fail unless peek == :ok
        end

        def detail
          :ok
        end
      end

      expect {
        job.perform_now(entry)
      }.not_to raise_error
    end
  end

  describe "Recursive peeking" do
    it "does not work" do
      job.class_eval do
        route.path "/graph/index.html", to: :index
        route.path "/graph/details/a.html", to: :a
        route.path "/graph/details/a.html", to: :b

        def index
          peek = yield "http://localhost:9876/graph/details/a.html"
          fail unless peek == :ok
        end

        def a
          yield "http://localhost:9876/graph/details/b.html" or :ok
        end

        def b
          yield "http://localhost:9876/graph/details/a.html"
        end
      end

      expect {
        job.perform_now(entry)
      }.not_to raise_error
    end
  end
end
