# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer::Routing::FiletypesRule do
  subject(:rule) { FiletypesRule.new([:png, :js]) }

  describe "#matches?" do
    context "with matching URI" do
      it "returns true" do
        uris = %w(
          http://example.com/foo.png
          https://example.com/a/b.png/c.png
          http://example.com/foobar.html.png
          https://example.com/foo.png/bar.png
        ).map { |u| URI(u) }

        uris.each do |uri|
          expect(rule.matches?(uri)).to be true
        end
      end
    end

    context "with mismatching URI" do
      it "returns false" do
        uris = %w(
          http://example.png
          http://example.com.png
          https://example.com/a/b.png/c
          http://example.com.html
          http://example.com/foobar.html
          https://example.com/foo.png/bar.png.html
        ).map { |u| URI(u) }

        uris.each do |uri|
          expect(rule.matches?(uri)).to be false
        end
      end
    end
  end
end
