# frozen_string_literal: true
require "spec_helpers"

describe Wayfarer::Routing::PathRule, mri: true do
  describe "#matches?" do
    context "with a string" do
      subject(:rule) { PathRule.new("/{alpha}/{beta}") }

      context "with matching URI" do
        let(:uri) { URI("http://example.com/foo/bar") }

        it "returns true" do
          expect(rule.matches?(uri)).to be true
        end
      end

      context "with mismatching URI" do
        let(:uri) { URI("http://example.com/foo") }

        it "returns false" do
          expect(rule.matches?(uri)).to be false
        end
      end
    end

    context "with a RegExp" do
      subject(:rule) { PathRule.new(/\/(\w+)\/(\w+)/) }

      context "with matching URI" do
        let(:uri) { URI("http://example.com/foo/bar") }

        it "returns true" do
          expect(rule.matches?(uri)).to be true
        end
      end

      context "with mismatching URI" do
        let(:uri) { URI("http://example.com/foo") }

        it "returns false" do
          expect(rule.matches?(uri)).to be false
        end
      end
    end
  end

  describe "#params" do
    context "with a string" do
      subject(:rule) { PathRule.new("/{alpha}/{beta}") }

      it "returns the correct parameters" do
        uri = URI("http://example.com/foo/bar")
        expect(rule.params(uri)).to eq("alpha" => "foo", "beta" => "bar")
      end
    end

    context "with a RegExp" do
      subject(:rule) { PathRule.new(/\/(\w+)\/(\w+)/) }

      it "returns the correct parameters" do
        uri = URI("http://example.com/foo/bar")
        expect(rule.params(uri)).to eq("0" => "foo", "1" => "bar")
      end
    end
  end
end
