# frozen_string_literal: true
require_relative "../lib/wayfarer"

require("bundler") && Bundler.require

include Wayfarer
include Wayfarer::HTTPAdapters
include Wayfarer::Routing
include Wayfarer::Frontiers

if RUBY_PLATFORM == "java"
  Wayfarer::Frontiers::MemoryBloomfilter  = \
  Wayfarer::Frontiers::MemoryTrieFrontier = \
  Wayfarer::Frontiers::RedisBloomfilter   = nil
end

Dir["./spec/shared/**/*.rb"].sort.each { |file| require file }

module SpecHelpers
  def jruby?
    RUBY_PLATFORM == "java"
  end

  def test_app(path)
    URI("http://localhost:9876#{path}")
  end

  def fetch_page(uri)
    NetHTTPAdapter.instance.fetch(URI(uri))
  end

  def html_fragment(html)
    Nokogiri::HTML.fragment(html)
  end

  def node_set(html)
    html_fragment(html).css("*")
  end
end

RSpec.configure do |config|
  config.include(SpecHelpers)

  config.before do
    Wayfarer.config.reset!
    Wayfarer.config.selenium_argv = [:phantomjs]
  end

  config.before(integration: true) do
    Wayfarer.logger.level = :fatal
  end

  config.after(integration: true) do
    Wayfarer.logger.level = :debug
  end

  config.before(mri_only: true) do
    skip("Not supported on JRuby") and fail if RUBY_PLATFORM == "java"
  end

  config.alias_example_to :they
end
